@@ -41,7 +41,7 @@ cp "txts/list_of_shortcuts/en_US" "txts/list_of_shortcuts/$LANG_CODE"
 
 echo "Processing completed for language code: $LANG_CODE"
 
-python3 updating/create_gresource_xml.py
-python3 updating/update_makefile.py
-python3 updating/update_translations_in_kickshaw_c.py
-python3 updating/update_version_and_year.py
+python3 called_scripts/create_gresource_xml.py
+python3 called_scripts/update_makefile.py
+python3 called_scripts/update_translations_in_kickshaw_c.py
+python3 called_scripts/update_version_and_year.py
