@@ -5,7 +5,7 @@ import polib
 
 # Groups of msgids
 GROUPS = {
-    1: ["_File", "_Edit", "_Search", "_View", "_Options", "_Help", "_Menu", "_Pipe Menu", "_Item", "Separato_r", "_Action"],
+    1: ["_File", "_Edit", "_Search", "_View", "_Preferences", "_Help", "_Menu", "Pipe Men_u", "_Item", "Separato_r", "_Action"],
     2: ["_Cancel", "_Same Level", "_Inside Menu"],
     3: ["_File", "_View", "_Help", "_Done", "_Cancel"],
     4: ["_File", "_View", "_Help", "_Cancel", "_Reset", "_Done"],
@@ -18,14 +18,14 @@ GROUPS = {
     11: ["_Visualize", "_Keep as is", "_Delete"],
     12: ["_Cancel", "C_ontinue"],
     13: ["_Restore Menu", "_Delete Autosave"],
-    14: ["_File", "_Edit", "_Search", "_View", "_Options", "_Help", "_Prompt"],
-    15: ["_File", "_Edit", "_Search", "_View", "_Options", "_Help", "_Command"],
-    16: ["_File", "_Edit", "_Search", "_View", "_Options", "_Help", "Startup_notify"],
-    17: ["_File", "_Edit", "_Search", "_View", "_Options", "_Help", "_Icon"],
-    18: ["_File", "_Edit", "_Search", "_View", "_Options", "_Help", "_Name"],
-    19: ["_File", "_Edit", "_Search", "_View", "_Options", "_Help", "E_nabled"],
-    20: ["_File", "_Edit", "_Search", "_View", "_Options", "_Help", "_WM__CLASS"],
-    21: ["_File", "_Edit", "_Search", "_View", "_Options", "_Help", "O_ption"],
+    14: ["_File", "_Edit", "_Search", "_View", "_Preferences", "_Help", "Pro_mpt"],
+    15: ["_File", "_Edit", "_Search", "_View", "_Preferences", "_Help", "_Command"],
+    16: ["_File", "_Edit", "_Search", "_View", "_Preferences", "_Help", "Startup_notify"],
+    17: ["_File", "_Edit", "_Search", "_View", "_Preferences", "_Help", "_Icon"],
+    18: ["_File", "_Edit", "_Search", "_View", "_Preferences", "_Help", "_Name"],
+    19: ["_File", "_Edit", "_Search", "_View", "_Preferences", "_Help", "E_nabled"],
+    20: ["_File", "_Edit", "_Search", "_View", "_Preferences", "_Help", "_WM__CLASS"],
+    21: ["_File", "_Edit", "_Search", "_View", "_Preferences", "_Help", "_Option"],
     22: ["The Menu _File", "_Working With Kickshaw", "_Miscellaneous"],
 }
 
